@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2021-12-07 19:02:19
+@LastEditTime: 2022-01-04 16:38:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -32,7 +32,7 @@ class ActInfoHandler(ClientBaseHandler):
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
             return self.response_json_error("error", "小程序不存在")
-        act_info_dict = act_base_model.get_act_info_dict(act_id)
+        act_info_dict = act_base_model.get_act_info_dict(act_id, True, False)
         if not act_info_dict:
             return self.response_json_error("error", "活动不存在")
         invoke_result_data = self.business_process_executing()
@@ -102,14 +102,13 @@ class CmsInfoListHandler(ClientBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         page_index = int(self.get_param("page_index", 0))
 
-        order_by = "id desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
         page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True), ref_params={})
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
