@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 09:24:50
-@LastEditTime: 2021-12-20 17:37:24
+@LastEditTime: 2021-12-21 19:49:18
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -24,11 +24,12 @@ class SkuInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        is_log = bool(self.get_param("is_log", False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
         num_iid = self.get_param("num_iid")
         if not num_iid:
             num_iid = self.get_param("num_iids")
-        if not num_iid: 
+        if not num_iid:
             return self.response_json_error("param_error", "参数错误,缺少必传参数")
         top_base_model = TopBaseModel(context=self)
         app_base_model = AppBaseModel(context=self)
@@ -65,7 +66,8 @@ class GoodsListHandler(ClientBaseHandler):
         app_id = self.get_source_app_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = self.get_param("page_size", 10)
-        is_log = bool(self.get_param("is_log", False))
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
 
         top_base_model = TopBaseModel(context=self)
         app_base_model = AppBaseModel(context=self)
