@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-12-30 11:52:05
+@LastEditTime: 2021-12-30 13:56:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -38,15 +38,15 @@ class HorseracelampListHandler(ClientBaseHandler):
 
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
-        condition = f"create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            if invoke_result_data.data:
-                condition = invoke_result_data.data.get("condition", f"create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'")
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else f"create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_base_model = OrderBaseModel(context=self)
-        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(act_id, module_id, is_search_module, condition, page_size), ref_params={})
+        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(act_id, module_id, is_search_module, condition, params, page_size), ref_params={})
         return self.response_json_success(horseracelamp_list)
 
 
@@ -78,6 +78,8 @@ class SyncPayOrderHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
         app_key, app_secret = self.get_app_key_secret()
         order_base_model = OrderBaseModel(context=self)
         asset_type = invoke_result_data.data["asset_type"] if invoke_result_data.data.__contains__("asset_type") else 3
@@ -288,10 +290,9 @@ class SelectPrizeOrderHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        else:
-            if invoke_result_data.data:
-                if invoke_result_data.data.__contains__("prize_ids"):
-                    prize_ids = invoke_result_data.data["prize_ids"]
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        prize_ids = invoke_result_data.data["prize_ids"] if invoke_result_data.data.__contains__("prize_ids") else prize_ids
         invoke_result_data = order_base_model.select_prize_order(app_id, act_id, user_id, login_token, prize_ids, real_name, telephone, province, city, county, street,address)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
