@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-12-30 14:16:04
+@LastEditTime: 2022-01-12 10:50:32
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -512,7 +512,11 @@ class JoinMemberHandler(ClientBaseHandler):
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
+        app_key, app_secret = self.get_app_key_secret()
+        app_base_model = AppBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id)
+        access_token = app_info_dict["access_token"] if app_info_dict else ""
+        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, access_token, app_key, app_secret, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
