@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-01-10 14:38:30
+@LastEditTime: 2022-01-14 14:13:25
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -51,14 +51,19 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
         :last_editors: HuangJianYi
         """
-        if self.__class__.__name__ == "IndexHandler":
-            return
-        self.is_encrypt = False
-        #获取请求参数
-        self._convert_request_params()
-        # 标记日志请求关联
-        dict_param = self.get_http_log_extra_dict()
-        self._build_http_log(dict_param)
+        try:
+            if self.__class__.__name__ == "IndexHandler":
+                return
+            self.is_encrypt = False
+            #获取请求参数
+            self._convert_request_params()
+            # 标记日志请求关联
+            dict_param = self.get_http_log_extra_dict()
+            self._build_http_log(dict_param)
+        except Exception as ex:
+            if not hasattr(self, "request_code"):
+                self.request_code = UUIDHelper.get_uuid()
+            self.logging_link_error("【公共handler基类】" + traceback.format_exc())
 
     def options_async(self):
         self.response_json_success()
@@ -329,6 +334,8 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         result = False, ""
+        if config.get_value("is_pressure_test",False): #是否进行压力测试
+            return result
         if object_id and handler_name and app_id:
             sign = self.get_signature_md5(self.request_params)
             if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
@@ -584,13 +591,11 @@ class ClientBaseHandler(FrameBaseHandler):
     """
     :description: 客户端handler基类
     """
-
     def prepare(self):
         """
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
         :last_editors: HuangJianYi
         """
-
         if self.__class__.__name__ == "IndexHandler":
             return
 
@@ -640,6 +645,8 @@ class ClientBaseHandler(FrameBaseHandler):
                 self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
 
         except Exception as ex:
+            if not hasattr(self, "request_code"):
+                self.request_code = UUIDHelper.get_uuid()
             self.logging_link_error("【客户端handler基类】" + traceback.format_exc())
 
     def get_online_url(self, act_id, app_id, module_id=0):
