@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2021-12-30 11:42:33
+@LastEditTime: 2021-12-30 13:57:51
 @LastEditors: HuangJianYi
 @Description: ip模块
 """
@@ -82,19 +82,15 @@ class IpInfoListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        field = "*"
-        condition = ""
-        params = []
-        order_by = "sort_index desc"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            if invoke_result_data.data:
-                field = invoke_result_data.data.get("field","*")
-                condition = invoke_result_data.data.get("condition","")
-                params = invoke_result_data.data.get("params",[])
-                order_by = invoke_result_data.data.get("order_by","sort_index desc")
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
         page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, field, condition, params, order_by, is_cache=False)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
