@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-11-11 13:37:08
+@LastEditTime: 2022-01-10 13:54:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -94,7 +94,13 @@ class TikTokHelper:
             'grant_type': grant_type,
         }
         response = None
+        redis_init = SevenHelper.redis_init()
+        redis_key = f"tiktok_access_token:{str(app_id)}"
         try:
+            access_token = redis_init.get(redis_key)
+            if access_token:
+                invoke_result_data.data = access_token
+                return invoke_result_data
             requset_url = 'https://developer.toutiao.com/api/apps/token'
             headers = {"Content-type": "application/json"}
             response = requests.post(requset_url, headers=headers, data=json.dumps(param))
@@ -104,7 +110,8 @@ class TikTokHelper:
                 invoke_result_data.error_code = response_data["err_no"]
                 invoke_result_data.error_message = response_data["err_tips"]
                 return invoke_result_data
-            invoke_result_data.data = response_data["data"]
+            invoke_result_data.data = str(response_data["access_token"])
+            redis_init.set(redis_key, invoke_result_data.data, ex=3600)
             return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【get_access_token】" + traceback.format_exc())
@@ -654,4 +661,4 @@ class TikTokBizDataCrypt:
         return decrypted
 
     def _unpad(self, s):
-        return s[:-ord(s[len(s) - 1:])]
\ No newline at end of file
+        return s[:-ord(s[len(s) - 1:])]
