@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-12-21 15:23:50
+@LastEditTime: 2022-01-13 14:49:03
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,8 +22,10 @@ class AppBaseModel():
     """
     :description: 应用信息业务模型
     """
-    def __init__(self, context):
+    def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def get_app_id(self,store_name):
         """
