@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-12-21 10:24:23
+@LastEditTime: 2022-01-13 14:31:54
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -18,9 +18,11 @@ class AssetBaseModel():
     """
     :description: 资产管理业务模型
     """
-    def __init__(self, context, logging_error=None):
+    def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
         self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
+
 
     def _delete_asset_dependency_key(self,act_id,user_id):
         """
