@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-12-16 10:00:59
+@LastEditTime: 2022-01-14 14:15:03
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -82,9 +82,9 @@ class StatConsoleModel():
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
+                                    stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
                                 else:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
+                                    stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
                                 if stat_log_total > 0:
                                     is_add = False
 
@@ -100,8 +100,8 @@ class StatConsoleModel():
                             stat_log.create_month = create_month_int
                             stat_log.create_date = create_date
 
-                            stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
+                            stat_report_condition = "app_id=%s and act_id=%s and module_id=%s and key_name=%s and create_day=%s"
+                            stat_report_param = [stat_queue.app_id, stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
                             stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
                             db_transaction.begin_transaction()
@@ -179,9 +179,9 @@ class StatConsoleModel():
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
-                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
+                            stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue_dict["app_id"],stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
                         else:
-                            stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
+                            stat_log_total = stat_log_model.get_cache_total("app_id=%s and act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue_dict["app_id"], stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
                         if stat_log_total > 0:
                             is_add = False
 
@@ -197,8 +197,8 @@ class StatConsoleModel():
                     stat_log.create_month = create_month_int
                     stat_log.create_date = create_date
 
-                    stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
+                    stat_report_condition = "app_id=%s and act_id=%s and module_id=%s and key_name=%s and create_day=%s"
+                    stat_report_param = [stat_queue_dict["app_id"], stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
                     stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
                     db_transaction.begin_transaction()
