@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2021-12-07 18:44:34
+@LastEditTime: 2021-12-15 11:46:42
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -48,3 +48,5 @@ class TaskType(Enum):
     browse_special_topic = 12
     # 累计签到，格式：{"day_list":{"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0},"asset_object_id":"","is_loop":1} 字段说明： day_list:每天奖励配置列表 asset_object_id:资产对象标识 is_loop:是否循环1是0否
     cumulative_sign = 13
+    # 分享，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
+    share = 14
