@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-12-28 17:27:51
+@LastEditTime: 2022-01-12 15:30:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -122,7 +122,7 @@ class FrameBaseModel():
         else:
             return "交易成功"
 
-    def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1):
+    def business_process_executing(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_new_user=False,check_user_nick=True,continue_request_expire=5,acquire_lock_name="",request_limit_num=0,request_limit_time=1,source_object_id=""):
         """
         :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
         :param app_id:应用标识
@@ -137,6 +137,7 @@ class FrameBaseModel():
         :param acquire_lock_name:分布式锁名称，为空则不开启分布式锁校验功能
         :param request_limit_num:请求限制数(指的是当前接口在指定时间内可以请求的次数，用于流量削峰，减少短时间内的大量请求)；0不限制
         :param request_limit_time:请求限制时间；默认1秒
+        :param source_object_id:来源对象标识
         :return:
         :last_editors: HuangJianYi
         """
@@ -150,7 +151,10 @@ class FrameBaseModel():
 
         #请求太频繁限制
         if continue_request_expire > 0:
-            if SevenHelper.is_continue_request(f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}",expire=continue_request_expire*1000) == True:
+            continue_request_key = f"request_business_executing:{handler_name}_{act_id}_{module_id}_{user_id}"
+            if source_object_id:
+                continue_request_key += f"_{source_object_id}"
+            if SevenHelper.is_continue_request(continue_request_key, expire=continue_request_expire * 1000) == True:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
