@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-12-30 11:41:31
+@LastEditTime: 2022-01-13 14:51:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,8 +16,10 @@ class IpBaseModel():
     """
     :description: IP信息业务模型
     """
-    def __init__(self, context):
+    def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def _delete_ip_info_dependency_key(self,act_id):
         """
