@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2021-09-18 11:49:54
+@LastEditTime: 2022-01-13 14:52:49
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,8 +16,10 @@ class ModuleBaseModel():
     """
     :description: 活动模块业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
 
     def _delete_act_module_dependency_key(self,act_id,module_id):
