@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-12-20 16:07:52
-@LastEditTime: 2021-12-23 11:47:54
+@LastEditTime: 2022-01-13 14:53:11
 @LastEditors: HuangJianYi
 @Description: 中台接口相关处理业务模型
 """
@@ -14,8 +14,10 @@ class MPBaseModel():
     """
     :description: 中台接口相关处理业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def get_project_code_list(self, project_code):
         """
