@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-01-06 17:57:11
+@LastEditTime: 2022-01-13 15:09:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,8 +26,10 @@ class OrderBaseModel(FrameBaseModel):
     """
     :description: 订单和中奖记录相关业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None,logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
         super(OrderBaseModel,self).__init__(context)
 
     def _delete_prize_order_dependency_key(self, act_id, user_id):
@@ -202,7 +204,10 @@ class OrderBaseModel(FrameBaseModel):
                 return invoke_result_data
 
         except Exception as ex:
-            self.context.logging_link_error(traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error(traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error(traceback.format_exc())
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
             invoke_result_data.success = False
@@ -329,7 +334,7 @@ class OrderBaseModel(FrameBaseModel):
 
     def get_tao_pay_order_list(self,app_id,act_id,user_id,open_id,nick_name,pay_date_start,pay_date_end,page_size=20,page_index=0,field="*",order_by="pay_date desc",condition="",params=[]):
         """
-        :description: 用户购买订单列表
+        :description: 淘宝用户购买订单列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_id：用户唯一标识
@@ -489,7 +494,10 @@ class OrderBaseModel(FrameBaseModel):
         except Exception as ex:
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
-            self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("create_prize_order:" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起,下单失败"
@@ -657,7 +665,10 @@ class OrderBaseModel(FrameBaseModel):
                                 pay_num = pay_num + 1
                                 buy_num = buy_num + order['num']
                         except Exception as ex:
-                            self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + traceback.format_exc())
+                            if self.context:
+                                self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + traceback.format_exc())
+                            elif self.logging_link_info:
+                                self.logging_link_info(str(order) + "【同步淘宝支付订单】" + traceback.format_exc())
                             continue
                     if len(tao_pay_order_list) > 0:
                         result = TaoPayOrderModel(context=self.context).add_list(tao_pay_order_list)
@@ -702,7 +713,10 @@ class OrderBaseModel(FrameBaseModel):
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "没有订单"
         except Exception as ex:
-            self.context.logging_link_error("【同步淘宝支付订单】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【同步淘宝支付订单】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【同步淘宝支付订单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
