@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-12-16 09:18:13
+@LastEditTime: 2022-01-13 14:56:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,8 +17,10 @@ class PrizeBaseModel():
     """
     :description: 活动奖品业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None,logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def _delete_act_prize_dependency_key(self,act_id,prize_id):
         """
@@ -36,7 +38,7 @@ class PrizeBaseModel():
                 redis_init.delete(f"act_prize_list:actid_{act_id}")
         except Exception as ex:
             pass
-             
+
     def get_act_prize_dict(self,prize_id,is_cache=True,is_filter=True):
         """
         :description: 获取活动模块
@@ -97,7 +99,7 @@ class PrizeBaseModel():
         if is_cache:
             page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
         else:
-            page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
+            page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
     def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
@@ -152,7 +154,7 @@ class PrizeBaseModel():
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        
+
         is_add = False
         old_act_prize = None
         act_prize = None
@@ -209,10 +211,10 @@ class PrizeBaseModel():
         act_prize.d1 = d1
         act_prize.d2 = d2
         act_prize.modify_date = now_datetime
-        
+
         # 奖品类型为参与奖时
         prize_total = 9999 if prize_type == 4 else prize_total
-        
+
         if is_add:
             act_prize.create_date = now_datetime
             act_prize.surplus = prize_total
@@ -223,7 +225,7 @@ class PrizeBaseModel():
             operate_num = prize_total - act_prize.prize_total
             if operate_num != 0:
                 act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
-            
+
         result = {}
         result["is_add"] = is_add
         result["new"] = act_prize
@@ -231,7 +233,7 @@ class PrizeBaseModel():
         invoke_result_data.data = result
         self._delete_act_prize_dependency_key(act_id,act_prize.id)
         return invoke_result_data
-    
+
     def save_tao_coupon(self,app_id,act_id,prize_id,coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,coupon_url,coupon_price,use_sill_price):
         """
         :description: 添加奖品关联优惠券
@@ -294,7 +296,7 @@ class PrizeBaseModel():
         invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, prize_id])
         self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
-    
+
     def release_act_prize(self,app_id,prize_id,is_release):
         """
         :description: 活动奖品上下架
@@ -316,7 +318,3 @@ class PrizeBaseModel():
         invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, prize_id])
         self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
-
-    
-
-    
\ No newline at end of file
