@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2021-12-06 18:31:12
+@LastEditTime: 2022-01-13 15:04:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,8 +19,10 @@ class ThemeBaseModel():
     """
     :description: 主题皮肤业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None,logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def get_theme_info(self,theme_id, ver_no,is_cache=True):
         """
