@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-27 20:07:13
+@LastEditTime: 2022-01-13 14:43:56
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -16,7 +16,7 @@ class TopBaseModel():
     """
     :description: 淘宝top接口业务模型
     """
-    def __init__(self,context,logging_error=None,logging_info=None):
+    def __init__(self,context=None,logging_error=None,logging_info=None):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
