@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-01-05 15:05:51
+@LastEditTime: 2022-01-13 15:08:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,8 +22,10 @@ class UserBaseModel(FrameBaseModel):
     """
     :description: 用户信息业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
         super(UserBaseModel,self).__init__(context)
 
     def _get_user_info_id_md5(self, act_id, user_id):
@@ -262,7 +264,10 @@ class UserBaseModel(FrameBaseModel):
                 self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         except Exception as ex:
-            self.context.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
 
@@ -331,7 +336,10 @@ class UserBaseModel(FrameBaseModel):
                     user_account_model.update_table(update_sql, "id=%s", params=params)
 
         except Exception as ex:
-            self.context.logging_link_error("【更新用户信息】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【更新用户信息】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【更新用户信息】" + traceback.format_exc())
 
         return invoke_result_data
 
@@ -442,7 +450,10 @@ class UserBaseModel(FrameBaseModel):
         except Exception as ex:
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
-            self.context.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -728,7 +739,10 @@ class UserBaseModel(FrameBaseModel):
                         user_black_model.add_entity(user_black)
                     self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
         except Exception as ex:
-            self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
+            if self.context:
+                self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
+            elif self.logging_link_error:
+                self.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
             result = False
         return result
 
